*************
Miscellaneous
*************

Links to examples of code using execo
=====================================

- *funk*, a tool that help you to find ressources for experiments on
  the grid5000 platform: https://github.com/lpouillo/Funk

- *g5k_bench_flops*, to automate flops benchmarking of grid5000
  clusters: https://github.com/mimbert/g5k_bench_flops

- *vm5k*: a module to ease the experimentations of virtual machines for
  the grid5000 platform: https://github.com/lpouillo/vm5k

- *execo-g5k-tools*: a github repository of various user-contributed
  code of tools or experiments on grid5000:
  https://github.com/lpouillo/execo-g5k-tools
